
Open Asset Import Library Coding Conventions
==

If you want to participate as a developer in the **Open Asset Import Library** please read and respect the following coding conventions. This will ensure consistency throughout the codebase and help all the Open Asset Import Library users.

Spacing
==

* Use UNIX-style line endings (LF)
* Remove any trailing whitespace
* Expand tabs to 4 spaces
